@@ -117,10 +117,17 @@ QString BibleInfo::getVerseText(int book, int chapter, int verse)
 	key->Chapter(chapter + 1);
 	key->Verse(verse + 1);
 	QString text = mModule->RenderText(key);
+	text = text.replace("<scripRef", "<span class=\"scripRef\"");
+	text = text.replace("</scripRef>", "</span>");
 	delete key;
 	return text;
 }
 
+bool BibleInfo::isUnicode()
+{
+	return mModule->isUnicode();
+}
+
 void searchCallback(char percent, void* data)
 {
 	((QProgressDialog*)data)->setValue(percent);
@@ -207,6 +214,11 @@ public:
 		return mBible->getVerseText(mBookNum, section, paragraph);
 	}
 
+	virtual bool isUnicode()
+	{
+		return mBible->isUnicode();
+	}
+
 private:
 	BibleInfo* mBible;
 	QString mBookName;
